@@ -10,19 +10,31 @@ from kedro.pipeline import Pipeline
 from kedro.versioning.journal import _git_sha
 
 from kedro_mlflow.framework.context import get_mlflow_config
+from kedro_mlflow.io import MlflowMetricsDataSet
 from kedro_mlflow.mlflow import KedroPipelineModel
-from kedro_mlflow.pipeline.pipeline_ml import PipelineML
+from kedro_mlflow.pipeline.pipeline_ml_factory import PipelineML
 from kedro_mlflow.utils import _parse_requirements
 
 
 class MlflowPipelineHook:
-    def __init__(
+    @hook_impl
+    def after_catalog_created(
         self,
-        conda_env: Union[str, Path, Dict[str, Any]] = None,
-        model_name: Union[str, None] = "model",
+        catalog: DataCatalog,
+        conf_catalog: Dict[str, Any],
+        conf_creds: Dict[str, Any],
+        feed_dict: Dict[str, Any],
+        save_version: str,
+        load_versions: str,
+        run_id: str,
     ):
-        self.conda_env = _format_conda_env(conda_env)
-        self.model_name = model_name
+        for name, dataset in catalog._data_sets.items():
+            if isinstance(dataset, MlflowMetricsDataSet) and dataset._prefix is None:
+                if dataset._run_id is not None:
+                    catalog._data_sets[name] = MlflowMetricsDataSet(
+                        run_id=dataset._run_id, prefix=name
+                    )
+                catalog._data_sets[name] = MlflowMetricsDataSet(prefix=name)
 
     @hook_impl
     def before_pipeline_run(
@@ -117,36 +129,73 @@ class MlflowPipelineHook:
             pipeline_catalog = pipeline.extract_pipeline_catalog(catalog)
             artifacts = pipeline.extract_pipeline_artifacts(pipeline_catalog)
             mlflow.pyfunc.log_model(
-                artifact_path=self.model_name,
+                artifact_path=pipeline.model_name,
                 python_model=KedroPipelineModel(
                     pipeline_ml=pipeline, catalog=pipeline_catalog
                 ),
                 artifacts=artifacts,
-                conda_env=self.conda_env,
+                conda_env=_format_conda_env(pipeline.conda_env),
             )
         # Close the mlflow active run at the end of the pipeline to avoid interactions with further runs
         mlflow.end_run()
 
+    @hook_impl
+    def on_pipeline_error(
+        self,
+        error: Exception,
+        run_params: Dict[str, Any],
+        pipeline: Pipeline,
+        catalog: DataCatalog,
+    ):
+        """Hook invoked when the pipeline execution fails.
+         All the mlflow runs must be closed to avoid interference with further execution.
+
+        Args:
+            error: (Not used) The uncaught exception thrown during the pipeline run.
+            run_params: (Not used) The params used to run the pipeline.
+                Should be identical to the data logged by Journal with the following schema::
+
+                   {
+                     "run_id": str
+                     "project_path": str,
+                     "env": str,
+                     "kedro_version": str,
+                     "tags": Optional[List[str]],
+                     "from_nodes": Optional[List[str]],
+                     "to_nodes": Optional[List[str]],
+                     "node_names": Optional[List[str]],
+                     "from_inputs": Optional[List[str]],
+                     "load_versions": Optional[List[str]],
+                     "pipeline_name": str,
+                     "extra_params": Optional[Dict[str, Any]]
+                   }
+            pipeline: (Not used) The ``Pipeline`` that will was run.
+            catalog: (Not used) The ``DataCatalog`` used during the run.
+        """
+
+        while mlflow.active_run():
+            mlflow.end_run()
+
 
 def _generate_kedro_command(
     tags, node_names, from_nodes, to_nodes, from_inputs, load_versions, pipeline_name
 ):
     cmd_list = ["kedro", "run"]
     SEP = "="
-    if len(from_inputs) > 0:
+    if from_inputs:
         cmd_list.append("--from-inputs" + SEP + ",".join(from_inputs))
-    if len(from_nodes) > 0:
+    if from_nodes:
         cmd_list.append("--from-nodes" + SEP + ",".join(from_nodes))
-    if len(to_nodes) > 0:
+    if to_nodes:
         cmd_list.append("--to-nodes" + SEP + ",".join(to_nodes))
-    if len(node_names) > 0:
+    if node_names:
         cmd_list.append("--node" + SEP + ",".join(node_names))
     if pipeline_name:
         cmd_list.append("--pipeline" + SEP + pipeline_name)
-    if len(tags) > 0:
+    if tags:
         # "tag" is the name of the command, "tags" the value in run_params
         cmd_list.append("--tag" + SEP + ",".join(tags))
-    if len(load_versions) > 0:
+    if load_versions:
         # "load_version" is the name of the command, "load_versions" the value in run_params
         formatted_versions = [f"{k}:{v}" for k, v in load_versions.items()]
         cmd_list.append("--load-version" + SEP + ",".join(formatted_versions))
@@ -161,16 +210,17 @@ def _format_conda_env(
     """Best effort to get dependecies of the project.
 
     Keyword Arguments:
-        conda_env {[type]} -- It can be either :
+        conda_env {Union[str, Path, Dict[str, Any]]} -- It can be either :
             - a path to a "requirements.txt": In this case
             the packages are parsed and a conda env with
             your current python_version and these dependencies is returned
             - a path to an "environment.yml" : data is loaded and used as they are
             - a Dict : used as the environment
-            - None (default: {None})
+            - None: a base conda environment with your current python version and your project version at training time.
+            Defaults to None.
 
     Returns:
-        Dict[str, Any] -- [description]
+        Dict[str, Any] -- A dictionary which contains all informations to dump it to a conda environment.yml file.
     """
     python_version = ".".join(
         [
