@@ -1,5 +1,5 @@
-from .modular_pipeline_ml import pipeline_ml
 from .pipeline_ml import (
     KedroMlflowPipelineMLDatasetsError,
     KedroMlflowPipelineMLInputsError,
 )
+from .pipeline_ml_factory import pipeline_ml, pipeline_ml_factory
